Implementation and traits for mapping rust types to Arrow types

Structs

Represents the FixedSizeBinary Arrow type.
Represents the FixedSizeList Arrow type.
Maps a rust i128 to an Arrow Decimal where precision and scale are required.
Represents the LargeString Arrow type.
Represents the LargeUtf8 Arrow type
Represents the LargeList Arrow type.

Traits

Trait implemented by all types that can be used as an Arrow field.